==> tomboy-0.8.2.tar.bz2: tomboy-0.8.2/Mono.Addins/Mono.Addins/Mono.Addins/NodeElement.cs <==
//
// NodeElement.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;

namespace Mono.Addins
{
	public interface NodeElement
	{
		string NodeName { get; }
		string GetAttribute (string key);
		NodeAttribute[] Attributes { get; }
	}
	
	public class NodeAttribute
	{
		internal string name;
		internal string value;
		
		internal NodeAttribute ()
		{
		}
		
		public string Name {
			get { return name; }
		}
		
		public string Value {
			get { return value; }
		}
	}
}

==> tomboy-0.13.2.tar.bz2: tomboy-0.13.2/Mono.Addins/Mono.Addins/Mono.Addins/NodeElement.cs <==
//
// NodeElement.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2007 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;

namespace Mono.Addins
{
	public interface NodeElement
	{
		string NodeName { get; }
		string GetAttribute (string key);
		NodeAttribute[] Attributes { get; }
		NodeElementCollection ChildNodes { get; }
	}
	
	public class NodeAttribute
	{
		internal string name;
		internal string value;
		
		internal NodeAttribute ()
		{
		}
		
		public string Name {
			get { return name; }
		}
		
		public string Value {
			get { return value; }
		}
	}
	
	public interface NodeElementCollection: IList, ICollection, IEnumerable
	{
		new NodeElement this [int n] { get; }
	}
}
